@@ -1,15 +1,19 @@
 /*
-   $Id: quest.cc,v 1.6 2001/08/12 20:23:49 ksterker Exp $
-   
-   Copyright (C) 2000 Kai Sterker <kaisterker@linuxgames.com>
-   Part of the Adonthell Project http://adonthell.linuxgames.com
+   Copyright (C) 2000 Kai Sterker <kai.sterker@gmail.com>
+   Part of the Adonthell Project <http://adonthell.nongnu.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License.
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY.
+   Adonthell is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
-   See the COPYING file for more details.
+   Adonthell is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with Adonthell.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "quest.h"
