@@ -52,6 +52,7 @@ SDL_Renderer *screen::Renderer = NULL;
 u_int8 screen::mode_ = 0;
 u_int8 screen::scale_;
 SDL_Rect screen::clip_rect_ = {};
+SDL_DisplayMode screen::fullscreen_mode = {};
 
 void screen::cleanup()
 {
@@ -68,11 +69,11 @@ bool screen::init (u_int16 nl, u_int16 nh, u_int8 depth, const config & myconfig
 	u_int8 screen_mode = myconfig.screen_mode;
 
 #if defined(SDL_VIDEO_DRIVER_X11) || defined(SDL_VIDEO_DRIVER_WAYLAND)
-	std::string wm_class = "SDL_VIDEO_X11_WMCLASS=" + myconfig.game_name;
+	static std::string wm_class = "SDL_VIDEO_X11_WMCLASS=" + myconfig.game_name;
 	putenv ((char *) wm_class.c_str ());
 #endif
 
-    if (SDL_Init (SDL_INIT_VIDEO | SDL_INIT_AUDIO) < 0)
+    if (SDL_Init (SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_GAMECONTROLLER) < 0)
     {
     	std::cout << "Couldn't init SDL: " << SDL_GetError () << std::endl;
     	return false;
@@ -118,7 +119,6 @@ bool screen::init (u_int16 nl, u_int16 nh, u_int8 depth, const config & myconfig
 		}
 	}
 
-    SDL_DisplayMode fullscreen_mode;
     memset(&fullscreen_mode, 0, sizeof(SDL_DisplayMode));
     fullscreen_mode.format = SDL_PIXELFORMAT_RGB888;
 
@@ -208,19 +208,33 @@ string screen::info ()
     return temp.str ();
 }
 
+#ifdef DEBUG
+static const char* get_mode_str(const u_int8 & m)
+{
+	switch(m)
+	{
+	case 0: return "window";
+	case 1: return "letterbox";
+	case 2: return "fullscreen";
+	default: return "unknown";
+	}
+}
+#endif
+
 bool screen::set_fullscreen (const u_int8 & m)
 {
 	bool r = false;
     if (mode_ != m)
     {
 #ifdef DEBUG
-    	std::cout << "Switching from " << (int)mode_ << " to " << (int)m << std::endl;
+    	std::cout << "Switching from " << get_mode_str(mode_) << " to " << get_mode_str(m) << std::endl;
 #endif
     	if (mode_ != 0)
     	{
 			r = SDL_SetWindowFullscreen(Window, SDL_FALSE) == 0;
 			if (!r)
 			{
+	        	std::cout << "Failed to leave fullscreen mode: " << SDL_GetError() << std::endl;
 				return false;
 			}
     	}
@@ -264,10 +278,15 @@ bool screen::set_fullscreen (const u_int8 & m)
 		{
         	update_scale();
 		}
+        else
+        {
+        	std::cout << "Failed to enter fullscreen mode: " << SDL_GetError() << std::endl;
+        }
 
         return r; 
     }
-    return 0; 
+
+    return false;
 }
 
 u_int8 screen::get_scale_for_display(u_int8 screen, u_int16 nl, u_int16 nh)
@@ -290,17 +309,32 @@ u_int8 screen::get_scale_for_display(u_int8 screen, u_int16 nl, u_int16 nh)
 		}
 		case 2:
 		{
-			// fullscreen mode at 640x480
 			bounds.x = 0;
 			bounds.y = 0;
 			bounds.w = nl * 2;
 			bounds.h = nh * 2;
+
+			// fullscreen mode at highest supported multiple of 320x240
+			const int num_modes = SDL_GetNumDisplayModes(screen);
+			SDL_DisplayMode mode;
+			for (int i = 0; i < num_modes; ++i)
+			{
+				if (SDL_GetDisplayMode(screen, i, &mode) > -1)
+				{
+					if (mode.w % nl == 0 && mode.h % nh == 0)
+					{
+						bounds.w = mode.w;
+						bounds.h = mode.h;
+						break;
+					}
+				}
+			}
 			break;
 		}
 	}
 
-	int scale_x = (bounds.w - bounds.x) / nl;
-	int scale_y = (bounds.h - bounds.y) / nh;
+	int scale_x = bounds.w / nl;
+	int scale_y = bounds.h / nh;
 
 	return scale_x > scale_y ? scale_y : scale_x;
 }
@@ -309,12 +343,13 @@ void screen::update_scale()
 {
 	int w, h;
 
-	SDL_GetRendererOutputSize(Renderer, &w, &h);
+	if (SDL_GetRendererOutputSize(Renderer, &w, &h) == 0)
+	{
+		int scale_x = w / length();
+		int scale_y = h / height();
 
-	int scale_x = w / length();
-	int scale_y = h / height();
-
-	scale_ = scale_x > scale_y ? scale_y : scale_x;
+		scale_ = scale_x > scale_y ? scale_y : scale_x;
+	}
 
 	if (mode_ == 1)
 	{
@@ -338,7 +373,7 @@ void screen::update_scale()
 	}
 
 #ifdef DEBUG
-	std::cout << "Mode = " << (int) mode_ << ", X = " << offset_x_ << ", Y = " << offset_y_
+	std::cout << "Mode = " << get_mode_str(mode_) << ", X = " << offset_x() << ", Y = " << offset_y()
 			<< ", Width = " << w << ", Height = " << h << ", Scale = "
 			<< (int) (scale_) << std::endl;
 #endif
