@@ -1,13 +1,19 @@
-// $Id: types.h,v 1.16 2002/04/25 15:34:11 gnurou Exp $
 /*
    Copyright (C) 1999/2000/2001 Alexandre Courbot.
+   Part of the Adonthell Project <http://adonthell.nongnu.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License.
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY.
-   See the COPYING file for more details.
+   Adonthell is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
+   Adonthell is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with Adonthell.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -20,7 +26,7 @@
 #ifndef TYPES_H__
 #define TYPES_H__
 
-#include "SDL.h"
+#include <SDL.h>
 
 // We should put ifdefs here to put the correct int values accordingly to the system type
 
