@@ -1,20 +1,24 @@
 /*
-   $Id: yarg.h,v 1.3 2002/04/12 15:35:40 ksterker Exp $
+   (C) Copyright 1998/2002 Kai Sterker <kai.sterker@gmail.com>
+   Part of the Adonthell Project <http://adonthell.nongnu.org>
 
-   (C) Copyright 1998/2002 Kai Sterker <kaisterker@linuxgames.com>
-   Part of the Adonthell Project http://adonthell.linuxgames.com
+   Adonthell is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License.
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY.
+   Adonthell is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   See the COPYING file for more details
+   You should have received a copy of the GNU General Public License
+   along with Adonthell.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /**
  * @file   yarg.h
- * @author Kai Sterker <kaisterker@linuxgames.com>
+ * @author Kai Sterker <kai.sterker@gmail.com>
  * 
  * @brief  Yet Another Random Number Genarator.
  * 
